@@ -19,7 +19,7 @@
 #define EBT_LIMIT_AVG	"3/hour"
 #define EBT_LIMIT_BURST	5
 
-int string_to_number(const char *s, unsigned int min, unsigned int max,
+static int string_to_number(const char *s, unsigned int min, unsigned int max,
    unsigned int *ret)
 {
 	long number;
@@ -201,7 +201,7 @@ static int compare(const struct ebt_entry_match* m1,
 
 static struct ebt_u_match limit_match =
 {
-	.name		= EBT_LIMIT_MATCH,
+	.name		= "limit",
 	.size		= sizeof(struct ebt_limit_info),
 	.help		= print_help,
 	.init		= init,
