@@ -326,7 +326,7 @@ static int compare(const struct ebt_entry_match *m1,
 
 static struct ebt_u_match stp_match =
 {
-	.name		= EBT_STP_MATCH,
+	.name		= "stp",
 	.size		= sizeof(struct ebt_stp_info),
 	.help		= print_help,
 	.init		= init,
