@@ -1,8 +1,16 @@
+/* ebtable_broute
+ *
+ * Authors:
+ * Bart De Schuymer <bdschuym@pandora.be>
+ *
+ * April, 2002
+ */
+
 #include <stdio.h>
 #include "../include/ebtables_u.h"
 
 
-static void print_help(char **hn)
+static void print_help(const char **hn)
 {
 	printf("Supported chain for the broute table:\n");
 	printf("%s\n",hn[NF_BR_BROUTING]);
@@ -15,8 +23,7 @@ ebt_u_table table =
 	.help		= print_help,
 };
 
-static void _init(void) __attribute__ ((constructor));
-static void _init(void)
+void _init(void)
 {
-	register_table(&table);
+	ebt_register_table(&table);
 }
